@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright 2013-2017, Derrick Wood <dwood@cs.jhu.edu>
+# Copyright 2013-2019, Derrick Wood, Jennifer Lu <jlu26@jhmi.edu>
 #
 # This file is part of the Kraken taxonomic sequence classification system.
 
@@ -19,9 +19,9 @@ cd "$TAXONOMY_DIR"
 
 if [ ! -e "accmap.dlflag" ]
 then
-  wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_est.accession2taxid.gz
+  #wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_est.accession2taxid.gz
   wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_gb.accession2taxid.gz
-  wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_gss.accession2taxid.gz
+  #wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_gss.accession2taxid.gz
   wget $FTP_SERVER/pub/taxonomy/accession2taxid/nucl_wgs.accession2taxid.gz
   touch accmap.dlflag
   echo "Downloaded accession to taxon map(s)"
